//------------------------------------------------------------------------------//
//		AXC-PL01_SAMPLE1_CONFIGURATION OPTION REGISTERE Module  V1.20		//
//			CompactFlash CF+ Programmable Logic CARD					//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/01/13  LAST UPDATE 2005/11/07				//
//						<< S1_CONFIGURATION U0 >>					//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	Module	C_ -> CompactFlash, L_ ->LocalSignal, P -> PIO Signal			//
//			n  -> Active Low Signal									//
//------------------------------------------------------------------------------//

module S1_CONFIGURATION

	(	EE_C_DATA_I,
		EE_C_ADR_I,
		EE_C_nOE_I,
		EE_C_nWE_I,
		EE_C_nREG_I,
		EE_ROM_nROMOE_O,
		EE_ROM_nROMWE_O,
		EE_ROM_nROMCE_O,
		C_RESET,		
		COR_RST_O,
		COR_IOENB_O,
		COR_REG_O
	);


//-----------------------Input Signal Definition--------------------------------//

	input	[7:0]EE_C_DATA_I;			//  CompactFlash DATA Buses
									// (IO Buffer CompactFlash CARD DATA)
									// U2  U0,U1,U4

	input	[10:0]EE_C_ADR_I;			// CompactFlash ADDRESS
									// Card Bus  U0,U1,U3,U4

	input	EE_C_nOE_I;				// CompactFlash Memory Output Enable
									// Card Bus  U0,U3

	input	EE_C_nWE_I;				// CompactFlash Memory Write Enable
									// Card Bus  U0

	input	EE_C_nREG_I;				// CompactFlash Register Access
									// Card Bus  U0,U1,U3,U4

	input	C_RESET;					// CompactFlash RESET (Active"H")
									// Card Bus  U0,U3


//-----------------------Output Signal Definition-------------------------------//

	output	EE_ROM_nROMOE_O;			// Local ROM OutputEnable Signal
									// U0  Local said Bus

	output	EE_ROM_nROMWE_O;			// Local ROM Write Enable Signal
									// U0  Local said Bus

	output	EE_ROM_nROMCE_O;			// Local ROM Chip  Enable Signal
									// U0  Local said Bus

	output	COR_RST_O;				// Configuration Option Register
									// RESET TRIGGER Bit[7]
									// U0  MAIN

	output	COR_IOENB_O;				// Configuration Option Register
									// I/O Enable Bit[0] 200H <- 01H
									// U0  MAIN

	output	[7:0]COR_REG_O;			// Configuration Option Register
									// U0  U3


//------------------------------------------------------------------------------//
//	EEPROM ANZX`											//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	EEPROM Attribute Write Enable Address								//
//	200h3AނƃAgr[gݗL							//
//------------------------------------------------------------------------------//

	wire		ADR200;					// EEPROM Attribute Write Enable Address

	assign 	ADR200	= (EE_C_ADR_I  == 11'b010_0000_0000) && (EE_C_nREG_I == 0);

									
	wire		wen;						// EEPROM Attribute Writer Enable

	assign	wen		= COR_REG_O[5] & COR_REG_O[4] 
						& COR_REG_O[3] & COR_REG_O[1];


	wire		EE_ROM_nROMOE_O;
	assign	EE_ROM_nROMOE_O = ~(~EE_C_nOE_I & ~EE_C_nREG_I);

	wire		EE_ROM_nROMWE_O;
	assign 	EE_ROM_nROMWE_O = ~(~EE_C_nWE_I & ~EE_C_nREG_I & ~C_RESET & wen);

	wire		EE_ROM_nROMCE_O;
	assign	EE_ROM_nROMCE_O = ~(~EE_C_nREG_I & (EE_C_ADR_I[10:8] <= 3'b001) 
											& (EE_C_ADR_I[10:8] >= 3'b000));

//------------------------------------------------------------------------------//
//	I/O ANZX`											//
//------------------------------------------------------------------------------//

	wire		COR_RST_O;
	assign	COR_RST_O		= COR_REG_O[7];

	wire		COR_IOENB_O;
	assign	COR_IOENB_O	= COR_REG_O[0];


//------------------------------------------------------------------------------//
//																//
//	Configuration Option Register										//
//																//
//		[7:0]COR_REG_O												//
//																//
//		 7 6 5 4  3 2 1 0											//
//		 | | | |  | | | |											//
//		 | | | |  | | | +- COR_IOENB_O								//
//		 | | | |  | | +--- EEPROM Attribute Writer Enable[1]				//
//		 | | | |  | +----- IO_nREG_I									//
//		 | | | |  +------- EEPROM Attribute Writer Enable[3]				//
//		 | | | |													//
//		 | | | +---------- EEPROM Attribute Writer Enable[4]				//
//		 | | +------------ EEPROM Attribute Writer Enable[5]				//
//		 | +-------------- COR_IRQENB_O[6]								//
//		 +---------------- COR_RST_O									//
//																//
//	Configuration Option Register										//
//	@FCFJ[hI/Os߂ɗpӂKv̂郌WX^łB		//
//	    LWX^ݒ͋KiiCompactFlash Specification Revision 1.4j 	//
//	@@Ă܂B											//
//	    ڍׂɂĂ͐发ГłmFB						//
//																//
//------------------------------------------------------------------------------//

	reg		[7:0]COR_REG_O;				// Configuration Option Register


	always @ (posedge EE_C_nWE_I or posedge C_RESET) begin

		if(C_RESET) begin 
      		COR_REG_O[7:0] <= 8'b0000_0000;

  		end else begin

 			if (ADR200) begin
	  			COR_REG_O[7:0] <= EE_C_DATA_I[7:0];
			end

 		end
	end

//------------------------------------------------------------------------------//


endmodule
