//------------------------------------------------------------------------------//
//				AXC-PL01_SAMPLE1_MAIN Module  V1.20					//
//			CompactFlash CF+ Programmable Logic CARD					//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/01/13  LAST UPDATE 2005/11/07				//
//						Release 2005/11/07							//			
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	Module	C_ -> CompactFlash, L_ ->LocalSignal, P -> PIO Signal			//
//			n  -> Active Low Signal									//
//------------------------------------------------------------------------------//

module SAMPLE1_MAIN

	(	C_D,
	   	C_A,
		C_nCE,			 
		C_nIORD,
		C_nIOWR,
		C_nOE,
		C_nWE,
		C_nREG,
		C_RESET,
		C_WP_nIOIS16,
		C_nWAIT,
		C_nINPACK,
		L_n125GEN,
		L_nROMOE,
		L_nROMWE,
		L_nROMCE,
		P_DIO,
		P_GGND,

	    );

//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//					CompactFlash Side Signals						//
//------------------------------------------------------------------------------//

//-----------------------Inout Signal Definition--------------------------------//

	inout	[15:0]C_D;				// CompactFlash CARD DATA
									// Card Bus  U2

//-----------------------Input Signal Definition--------------------------------//

	input	[10:0]C_A;				// CompactFlash ADDRESS		:A[10:0]
									// Card Bus  U0,U1,U3,U4

	input	[2:1]C_nCE;				// CompactFlash CardEnable	:-CE[2:1]
									// Card Bus  U1,U3,U4

	input	C_nIORD;					// CompactFlash I/O Read
									// Card Bus  MAIN

	input	C_nIOWR;					// CompactFlash I/O Write
									// Card Bus  MAIN

	input	C_nOE;					// CompactFlash Memory Output Enable
									// Card Bus  U0,U3

	input	C_nWE;					// CompactFlash Memory Write Enable
									// Card Bus  U0

	input	C_nREG;					// CompactFlash Registor Access
									// Card Bus  U0,U1,U3,U4

	input	C_RESET;					// CompactFlash RESET
									// Card Bus  U0,U3

//-----------------------Output Signal Definition-------------------------------//

	output	C_WP_nIOIS16;				// CompactFlash Writeprotect or IO=16bit
									// U3  Card Bus

	output	C_nWAIT;					// CompactFlash WAIT Request
									// MAIN  Card Bus

	output	C_nINPACK;				// CompactFlash InputAcknowledge
									// U3  Card Bus


//------------------------------------------------------------------------------//
//					Local Side Signals								//
//------------------------------------------------------------------------------//

//-----------------------Input Signal Definition--------------------------------//

	input	L_n125GEN;				// Write Mode Switch
									// Local Switch  MAIN

	
//-----------------------Output Signal Definition-------------------------------//     

	output	L_nROMOE;					// Attribute memory rom output enable
									// U0  Local said Bus

	output	L_nROMWE;					// Attribute memory rom Write enable
									// U0  Local said Bus

	output	L_nROMCE;					// Attribute memory rom Chip enable
									// U0  Local said Bus


//------------------------------------------------------------------------------//
//					Parallel I/O Side Signals						//
//------------------------------------------------------------------------------// 

//-----------------------Inout Signal Definition--------------------------------//

	inout	[13:0]P_DIO;				// Parallel I/O
									// PIO Side Bus  U2

//-----------------------Output Signal Definition-------------------------------//

	output	[3:0]P_GGND;				// GrobalGround


//------------------------------------------------------------------------------//


//-----------------------WIRE definition----------------------------------------//

	wire		[13:0]n_cdataout;			// CARD DATA OUT
									// U3  U2
									 
	wire		[1:0]n_cdataout_en;			// CARD DATA OUT ENABLE
									// U3  MAIN,U2

	wire		[13:0]n_cdatain;			// CARD DATA BUS 
									// (IO Buffer CompactFlash CARD DATA)
									// U2  U0,U1

	wire		[13:0]n_iodataout;			// PIO DATA IO Register
									// U1  U2

	wire		[13:0]n_iodataout_en;		// PIO Output Enable
									// U1  U2,U3

	wire		[13:0]n_iodatain;			// OIO͂DATA
									// U2  U3

	wire		n_corioen;				// Configuration Option Register
									// I/O Enable Bit[0] 200H <- 01H
									// U0  MAIN

	wire		[7:0]cor_reg;				// Configuration Option Register
									// U0  U3


//------------------------------------------------------------------------------//


//------------------------------------------------------------------------------//
//	L_n125GEN_]												//
//																//
//   L_125GENgpL_n125GENhighANeBuɕύX܂B				//
//																//
//------------------------------------------------------------------------------//

	wire		L_125GEN;					// Write Mode Switch
									// MAIN  U1,U2
	assign	L_125GEN = ~L_n125GEN;


//------------------------------------------------------------------------------//
//	Programable Grand `											//
//																//
//   pI/O15pinGNDƂďo͂Ă܂B						//
//	46pin,56pin,74pin,82pin4_I/O pinCPLDڑĂ܂B		//
//																//
//------------------------------------------------------------------------------//

	wire		[3:0] P_GGND;				// Programable Grand
	assign 	P_GGND = 4'b0000;			// MAIN  PIO Side Bus


//------------------------------------------------------------------------------//
//	WAITM`													//
//																//
//   TvvOł͖gp̂߃vAbvB					//
//	46pin,56pin,74pin,82pin4_I/O pinCPLDڑĂ܂B		//
//																//
//------------------------------------------------------------------------------//

	wire		C_nWAIT;					// CARD WATI
									// MAIN  Card Bus
	assign 	C_nWAIT = 1'b1;			


//------------------------------------------------------------------------------//
//	MRST `														//
//																//
//   RtBM[VZbgM									//
//	J[h̃ZbgMAConfiguration Option Register ŏʃrbg		//
//	iSRESETjƂANDMłB										//
//																//
//------------------------------------------------------------------------------//

	wire		n_rst_U0;					// Configuration Option Register
									// RESET TRIGGER Bit[7]
									// U0  MAIN
									 
	wire		MRST;				    	// RtBM[VZbgM
									// MAIN  U1,U4

	assign 	MRST	 = C_RESET | n_rst_U0 | L_125GEN ;


//------------------------------------------------------------------------------//
//	REGISTERW[M										//
//																//
//	Tv\[XłREGISTERW[̓MƂăNbNM̕ς	//
//	ENIO_nIOWR_O MgpĂ܂B								//
//																//
//	ENIO_nIOWR_O M͉LLq̂ƂC_nIOWRMiCompactFlashIOWR	//
//	Mjn_corioenMiConfiguration Option Register I/O EnablejAND	//
//	쐬Ă܂B											//
//																//
//------------------------------------------------------------------------------//

//	ENIO_nIOWR_O	= I/O Write Enable M
//	n_corioen		= Configuration Option Register I/O Enable Bit
//	C_nIOWR		= CompactFlash IO Write 
	
	wire		ENIO_nIOWR_O;				// I/O Write Enable M
									// MAIN  U1
												  
	assign	ENIO_nIOWR_O = ~((~C_nIOWR) & (n_corioen));


//------------------------------------------------------------------------------//
//	READW[M											//
//																//
//	Tv\[XłREADW[̓MƂăNbNM̕ς	//
//	ENIO_nIORD MgpĂ܂B								//
//																//
//	ENIO_nIORD M͉LLq̂ƂC_nIORDMiCompactFlashIORD	//
//	Mjn_corioenMiConfiguration Option Register I/O EnablejAND	//
//	쐬Ă܂B											//
//																//
//------------------------------------------------------------------------------//

//	ENIO_nIORD	= I/O RDAD Enable M
//	n_corioen		= Configuration Option Register I/O Enable Bit
//

	wire		ENIO_nIORD_O;				// I/O Read Enable M
									// MAIN  U3

	assign	ENIO_nIORD_O = ~((~C_nIORD) & (n_corioen));


//------------------------------------------------------------------------------//
//	C_D[14],C_C[15] xŒ										//
//																//
//	gpf[^C_D[14],C_C[15]xŒ肵܂B						//
//																//
//------------------------------------------------------------------------------//


	wire		GND;
	assign	GND	= 1'b0;				

	OBUFT	C_D14 ( .O(C_D[14]),.I(GND),.T(n_cdataout_en[1]) );		
	OBUFT	C_D15 ( .O(C_D[15]),.I(GND),.T(n_cdataout_en[1]) );


//------------------------------------------------------------------------------//
//		W[ڑ`										//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//		NAME:CONFIGURATION REGISTER MODULE								//
//		:RtBM[VWX^							//
//			tbVANZXpfR[_[łB					//
//		U0														//
//------------------------------------------------------------------------------//

	S1_CONFIGURATION U0

	(  	.EE_C_DATA_I(n_cdatain[7:0]),
		.EE_C_ADR_I(C_A),		
		.EE_C_nOE_I(C_nOE),
		.EE_C_nWE_I(C_nWE),
		.EE_C_nREG_I(C_nREG),
		.EE_ROM_nROMOE_O(L_nROMOE),
		.EE_ROM_nROMWE_O(L_nROMWE),
		.EE_ROM_nROMCE_O(L_nROMCE),
		.C_RESET(C_RESET),		
		.COR_RST_O(n_rst_U0),
		.COR_IOENB_O(n_corioen),
		.COR_REG_O(cor_reg[7:0])
	);



//------------------------------------------------------------------------------//
//		NAME:REGISTER MODULE										//
//		:PIOӼޭق̃WX^i[prłB	    						//
//		U1														//
//------------------------------------------------------------------------------//

	S1_REGISTER U1

	(	.C_DATAIN_I(n_cdatain),
		.IO_C_ADR_I(C_A[3:0]),
		.IO_nCE_I(C_nCE[2:1]),
		.IO_nREG_I(C_nREG),
		.ENIO_nIOWR_I(ENIO_nIOWR_O),
		.MRST(MRST),		
		.IO_DATAOUT_O(n_iodataout),
		.IO_DATAOUT_EN_O(n_iodataout_en)

	);



//------------------------------------------------------------------------------//
//		NAME:OUTPUT MODULE											//
//		:OIOւI/OBufferprłB								//
//			GLOBAL I/O ӼޭقւȂĂ܂B						//
//		U2														//
//------------------------------------------------------------------------------//

	 S1_OUTPUT U2

	(	.IO_DATA_IO(P_DIO),
		.C_DATA_IO(C_D[13:0]),
		.IO_DATAOUT_I(n_iodataout),
		.IO_DATAOUT_EN_I(n_iodataout_en),
		.C_DATAOUT_I(n_cdataout),
		.C_DATAOUT_EN_I(n_cdataout_en),
		.L_125GEN(L_125GEN),
		.IO_DATAIN_O(n_iodatain),
		.C_DATAIN_O(n_cdatain)

	);




//------------------------------------------------------------------------------//
//		NAME:READ MODULE											//
//		:WX^̃[hpf[R[_łB@@@					//
//			b`؍Ȃ悤ɐ݌vĂ܂B					//
//		U3														//
//------------------------------------------------------------------------------//

	S1_READ U3

	(	.IO_nCE_I(C_nCE[2:1]),
		.IO_nREG_I(C_nREG),
		.COR_IOENB_I(n_corioen),
		.ENIO_nIORD_I(ENIO_nIORD_O),
		.IO_C_ADR_I(C_A[10:0]),
		.MEM_nOE(C_nOE),
		.IO_DATAIN_I(n_iodatain),
		.IO_DATAOUT_EN_I(n_iodataout_en),
		.COR_REG_I(cor_reg[7:0]),
		.C_RESET(C_RESET),
		.C_DATAOUT_O(n_cdataout),
		.C_DATAOUT_EN_O(n_cdataout_en),
		.IO_nINPACK_O(C_nINPACK),		 
		.IO_nIOIS16_O(C_WP_nIOIS16)
	);


//------------------------------------------------------------------------------//

endmodule
