//------------------------------------------------------------------------------//
//				AXC-PL01_SAMPLE2_REGISTER Module  V1.20					//
//			CompactFlash CF+ Programmable Logic CARD					//
//					ADTEK SYSTEM SCIENCE CO.,LTD.						//
//				Since 2005/01/13  LAST UPDATE 2005/11/07				//
//						<< S2_REGISTER U1 >>						//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//	Module	C_ -> CompactFlash, L_ ->LocalSignal, P -> PIO Signal			//
//			n  -> Active Low Signal									//
//------------------------------------------------------------------------------//

module S2_REGISTER

	(	C_DATAIN_I,
		IO_C_ADR_I,
		IO_nCE_I,
		IO_nREG_I,
		ENIO_nIOWR_I,
		MRST,
		IO_DATAOUT_O,
		IO_DATAOUT_EN_O,
		IO_DATAOUT_CT_O

	);


//-----------------------Input Signal Definition--------------------------------//

	input	[13:0] C_DATAIN_I;				//  CompactFlash DATA Buses
										// (IO Buffer CompactFlash CARD DATA)
										// U2  U0,U1,U4

	input	[3:0] IO_C_ADR_I;				// CompactFlash ADDRESS
										// Card Bus  U0,U1,U3,U4

	input	[2:1] IO_nCE_I;				// CompactFlash ChipEnable "H"Byte/"L"Byte
										// Card Bus @U1,U3,U4

	input	IO_nREG_I;					// CompactFlash Register Access
										// Card Bus  U0,U1,U3,U4

	input	ENIO_nIOWR_I;					// I/O Write Enable M
										// MAIN  U1

	input	MRST;						// RtBM[VZbgM
										// MAIN  U1,U4
													  	
//-----------------------Output Signal Definition-------------------------------//


	output	[13:0]IO_DATAOUT_O;				// DATA Register o
										// U1  U2

	output	[13:0]IO_DATAOUT_EN_O;			// I/O Select Register o
										// U1  U2,U3

	output	[1:0]IO_DATAOUT_CT_O;			// Counter Register@o
										// U1  U4

//-----------------------Register Definition------------------------------------//


	reg		[13:0]IO_DATAOUT_O;				// DATA Register

	reg		[13:0]IO_DATAOUT_EN_O;			// I/O Select Register

	reg		[1:0]IO_DATAOUT_CT_O;			// Counter Trigger Register




//------------------------------------------------------------------------------//
//			Register`											//
//------------------------------------------------------------------------------//

//------------------------------------------------------------------------------//
//			Data Register  (R/W)									//
//				I/Ox[XAhX +0								//
//				Register		= [13:0]IO_DATAOUT_O				//
//				Register Default 	= 0								//
//								@04/12/14 Ddefaulto0				//
// 				Low Rebel			= 0								//
//				Hight Revel		= 1								//
// 																//
// 				I/O Select Register Writer̎ Register data 		//
// 				I/O Select Register Read̎ Register data ǂݍ		//
// 																//
//------------------------------------------------------------------------------//

// LANZXCompactFlash Specification Revision 1.4 ɏĂ܂B
// ڍׂɂĂ͐发ГłmFB

// INDEX0W	= Data Register [hANZX
// INDEX0BL	= Data Register oCgANZXioCgANZXj
// INDEX0BH	= Data Register oCgANZXioCgANZXj
// INDEX0BHBA	= Data Register nCoCgANZXioCgANZXj

	wire		INDEX0W;
	assign	INDEX0W = (IO_C_ADR_I[3:1]	== 3'b000)
						&&(IO_nCE_I	== 2'b00);
 
	wire		INDEX0BL;
	assign	INDEX0BL =(IO_C_ADR_I[3:0]	== 4'b0000)
						&&(IO_nCE_I	== 2'b10);

	wire		INDEX0BH;
	assign	INDEX0BH = (IO_C_ADR_I[3:0]	== 4'b0001)
						 &&(IO_nCE_I	== 2'b10);

	wire		INDEX0BHBA;
	assign	INDEX0BHBA = (IO_C_ADR_I[3:1]	== 3'b000)
						 &&(IO_nCE_I	== 2'b01);

//------------------------------------------------------------------------------//

	always @(posedge ENIO_nIOWR_I or posedge MRST) begin

		if (MRST == 1) begin
			IO_DATAOUT_O[13:0]	<=	14'b11_1111_1111_1111;

		end

		else if (MRST	== 0) begin					
			
			if (IO_nREG_I	== 1'b0) begin 

				if (INDEX0W) begin
					IO_DATAOUT_O[13:0]	<=	C_DATAIN_I[13:0];

				end if (INDEX0BL) begin			
					IO_DATAOUT_O[7:0]	<=	C_DATAIN_I[7:0];
					IO_DATAOUT_O[13:8]	<=	IO_DATAOUT_O[13:8];

				end if (INDEX0BH) begin
					IO_DATAOUT_O[7:0]	<=	IO_DATAOUT_O[7:0];
					IO_DATAOUT_O[13:8]	<=	C_DATAIN_I[5:0];

				end if (INDEX0BHBA) begin
					IO_DATAOUT_O[7:0]	<=	IO_DATAOUT_O[7:0];
					IO_DATAOUT_O[13:8]	<=	C_DATAIN_I[13:8];

				end
			end
		end
	end


//------------------------------------------------------------------------------//
//			I/O Select Register (R/W)								//
//				I/Ox[XAhX +2								//
//				Register		= [13:0]IO_DATAOUT_EN_O				//
//				Register Default 	= 1								//				
// 				Write Mode Set		= 0								//
//				Read Mode Set		= 1								//
// 																//
//------------------------------------------------------------------------------//

// LANZXCompactFlash Specification Revision 1.4 ɏĂ܂B
// ڍׂɂĂ͐发ГłmFB

// INDEX2W	= I/O Select Register [hANZX
// INDEX2BL	= I/O Select Register oCgANZXioCgANZXj
// INDEX2BH	= I/O Select Register oCgANZXioCgANZXj
// INDEX2BHBA	= I/O Select Register nCoCgANZXioCgANZXj

	wire		INDEX2W;								
	assign	INDEX2W = (IO_C_ADR_I[3:1]	==	3'b001)
						&&(IO_nCE_I	==	2'b00);

	wire		INDEX2BL;								
	assign	INDEX2BL =(IO_C_ADR_I[3:0]	==	4'b0010)
						&&(IO_nCE_I	==	2'b10);

	wire		INDEX2BH;								
	assign	INDEX2BH = (IO_C_ADR_I[3:0]	==	4'b0011)
						 &&(IO_nCE_I	==	2'b10);

	wire		INDEX2BHBA;						
	assign	INDEX2BHBA = (IO_C_ADR_I[3:1]	==	4'b001)
						 &&(IO_nCE_I	==	2'b01);

//------------------------------------------------------------------------------//

	always @(posedge ENIO_nIOWR_I or posedge MRST) begin

		if (MRST == 1) begin
			IO_DATAOUT_EN_O[13:0]	<=	14'b11_1111_1111_1111;

		end

		else if (MRST == 0) begin					
		 	if (IO_nREG_I == 1'b0) begin 

				if (INDEX2W) begin					
					IO_DATAOUT_EN_O[13:0]	<=	C_DATAIN_I[13:0];

				end if (INDEX2BL) begin
					IO_DATAOUT_EN_O[7:0]	<=	C_DATAIN_I[7:0];
					IO_DATAOUT_EN_O[13:8]	<=	IO_DATAOUT_EN_O[13:8];

				end if (INDEX2BH) begin
					IO_DATAOUT_EN_O[7:0]	<=	IO_DATAOUT_EN_O[7:0];
					IO_DATAOUT_EN_O[13:8]	<=	C_DATAIN_I[5:0];

				end if (INDEX2BHBA) begin
					IO_DATAOUT_EN_O[13:8]	<=	C_DATAIN_I[13:8];
					IO_DATAOUT_EN_O[7:0]	<=	IO_DATAOUT_EN_O[7:0];
				end
			end
		end
	end

//------------------------------------------------------------------------------//


//------------------------------------------------------------------------------//
//			Counter Trigger Register (W)								//
//				I/Ox[XAhX +A								//
//				Register		= [13:0]counter					//
//				Register Default 	= 1								//				
// 				Count Mode Set		= 0								//
//				Stay Mode Set		= 1								//
// 																//
//------------------------------------------------------------------------------//

// LANZXCompactFlash Specification Revision 1.4 ɏĂ܂B
// ڍׂɂĂ͐发ГłmFB

// INDEXAW	= I/O Select Register [hANZX
// INDEXABL	= I/O Select Register oCgANZXioCgANZXj
// INDEXABH	= I/O Select Register oCgANZXioCgANZXj

	wire		INDEXAW;								
	assign	INDEXAW = (IO_C_ADR_I[3:1]	==	3'b101)
						&&(IO_nCE_I	==	2'b00);

	wire		INDEXABL;								
	assign	INDEXABL =(IO_C_ADR_I[3:0]	==	4'b1010)
						&&(IO_nCE_I	==	2'b10);

	wire		INDEXABH;								
	assign	INDEXABH = (IO_C_ADR_I[3:0]	==	4'b1011)
						 &&(IO_nCE_I	==	2'b10);

//------------------------------------------------------------------------------//

	always @(posedge ENIO_nIOWR_I or posedge MRST) begin

		if (MRST == 1) begin
			IO_DATAOUT_CT_O[1:0]	<=	2'b11;

		end

		else if (MRST == 0) begin					
		 	if (IO_nREG_I == 1'b0) begin 

				if (INDEXAW) begin					
					IO_DATAOUT_CT_O[1:0]	<=	C_DATAIN_I[1:0];

				end if (INDEXABL) begin
					IO_DATAOUT_CT_O[1:0]	<=	C_DATAIN_I[1:0];

				end if (INDEXABH) begin
					IO_DATAOUT_CT_O[1:0]	<=	IO_DATAOUT_CT_O[1:0];

				end
			end
		end
	end

//------------------------------------------------------------------------------//


endmodule

